/*
 * Copyright 2005, 2006 University of Leiden.
 *
 * This file is part of MIA+EWS.
 *
 * MIA+EWS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * MIA+EWS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with MIA; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/*******************************************************************************
* E.S.O. - VLT project
*
* "@(#) $Id: FLUORfsub.h,v 1.4 2002/05/08 21:24:47 jdejong Exp $"
*
* who       when      what
* --------  --------  ----------------------------------------------
* jdejong 2002-05-08  imported
*/

/************************************************************************
 *
 *----------------------------------------------------------------------
 */
/* $Id: FLUORfsub.h,v 1.4 2002/05/08 21:24:47 jdejong Exp $ */

#ifndef _FLUORFIT_H
#define _FLUORFIT_H
/*----------------------------------------------------------------------- */
/* Routines and parameters for FLUOR fringe fitting                       */
/*----------------------------------------------------------------------- */
#include <time.h>
#include <math.h>
#include <malloc.h>
#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include "imaging_detector.h"
#include "imaging_data.h"
#include "cal_table.h"
#include "visibility.h"
#include "image.h"
#include "history.h"

void setup_FLUORfringe_fit(char *pixfile, fitsfile *inputfptr, 
			   int nt, int nscan, int dophoto,
			   float OPD_incr,
			   imaging_detector_table_def* detector,
			   long input_nrows, long input_last);
/*----------------------------------------------------------------------- */
/*   Setup for fit MIDI Fourier Mode (undispersed) data                   */
/*   Necessary structures are allocated.                                  */
/*   Inputs:                                                              */
/*      pixfile   name of output Delay-rate image, NULL=>don't write      */
/*      inputfptr input file cfitsio pointer                              */
/*      nt        Number of samples per scan                              */
/*      nscan     Max. number of scans per solution                       */
/*      dophoto   if true (1) then apply photometric corrections          */
/*      time_incr Time step between samples in sec                        */
/*      ODP_incr  OPD step between samples in sec                         */
/*      detector  imaging_detector table definition structure             */
/*      input_nrows total number of rows in input                         */
/*      input_last  last row read in input                                */
/*----------------------------------------------------------------------- */

int  FLUOR_calib_data (float *IntChan, int nt, int iscan, int nscan, 
		       int chAv, int lo, int hi,
		       float OPD_range, float calDelay, float calPhase, 
		       float calRate, float ratefact, float weight,
		       visibility_row *visrow);
/*----------------------------------------------------------------------- */
/*   Apply calibration to MIDI Fourier mode (undispersed) data            */
/*   Steps:                                                               */
/*   Inputs:                                                              */
/*      IntChan   Difference array of two interferometric channels        */
/*                as complex values.                                      */
/*      nt        Number of frames in a scan                              */
/*      iscan     Which scan is this in the sequence                      */
/*      nscan     Total number of scans in the sequence                   */
/*      chAv      Number of spectral channels to average                  */
/*      chLo      First spectral channel to average                       */
/*      chHi      Highest spectral channel to average                     */
/*      OPD_range Range of modulation OPD in a scan (sec)                 */
/*      calDelay  Calibration delay (seconds)                             */
/*      calPhase  Calibration phase (radians)                             */
/*      calRate   Calibration rate*delta time (sec)                       */
/*      ratefact  Calibration rate scale compression factor               */
/*      weight    data weight for this interferogram                      */
/*   Outputs:                                                             */
/*      visrow    Visibility record, filled in on output                  */
/*   Returns                                                              */
/*      1 if there is valid data in the average and iscan=nscan, else 0   */
/*----------------------------------------------------------------------- */

void shutdown_FLUORfringe_fit(int *ierr);
/*----------------------------------------------------------------------- */
/*   Shutdown fit to FLUOR data                                           */
/*   All allocated structures are deleted.                                */ 
/*   Outputs:                                                             */
/*      ierr        Error code: 0 => ok                                   */
/*----------------------------------------------------------------------- */




void get_FLUOR_scan(fitsfile *fptr, imaging_data_table_def* tabledef, 
		    imaging_data_row *row, int maxstep, 
		    float *OPD_off, float *times, float *IntChan,
		    long *ntime, int *ierr);
void FLUOR_fringe_fit_data (float *IntChan, int nt, int nscan, 
			    float time_incr,
			    float *OPD_off, float *times, 
			    imaging_detector_table_def* detector,
			    cal_table_row *cal_row);
void FLUOR_find_delay1 (float *spectrum, int nf, float center,
		    float *delay, float *amp, float *phase, float *snr);
float FLUOR_int_spectrum (float *spectrum, int nf, float delay, float center,
		      float phase, float *re, float *im);
void  FLUOR_apply_cal(float *spectrum, int nf, float center, 
		      float delay, float phase, float rate, float ratefrac);
float FLUOR_find_centroid (float *array, int n);

void FOFT_in_time (float *array, int nt) ;

#endif /* end FLUORFIT_H */
/* */
